@@ -17,6 +17,7 @@
 import os.path
 import os
 import random
+import sys
 import logging
 from datetime import date
 from decimal import ROUND_DOWN, Decimal
@@ -28,6 +29,16 @@ if six.PY3:
 else:
     import cgi
 
+
+from gettext import gettext as _
+
+try:
+    if 'django' in sys.modules:
+        from django.utils.translation import ugettext_lazy as _
+except ImportError:
+    pass
+
+
 __all__ = ['PaymentCommon', 'URL', 'HTML', 'RANDOM', 'RECEIVED', 'ACCEPTED',
            'PAID', 'ERROR', 'WAITING']
 
