@@ -26,16 +26,13 @@ from .common import (
     ResponseError,
     URL,
     PAID, ERROR, WAITING,
-    force_text
+    force_text,
+    _
 )
 
 __all__ = ['Payment']
 
 
-def N_(message):
-    return message
-
-
 SERVICE_URL = 'http://dummy-payment.demo.entrouvert.com/'
 LOGGER = logging.getLogger(__name__)
 
@@ -65,31 +62,31 @@ class Payment(PaymentCommon):
         'parameters': [
             {
                 'name': 'normal_return_url',
-                'caption': N_('Normal return URL'),
+                'caption': _('Normal return URL'),
                 'default': '',
                 'required': True,
             },
             {
                 'name': 'automatic_return_url',
-                'caption': N_('Automatic return URL'),
+                'caption': _('Automatic return URL'),
                 'required': False,
             },
             {
                 'name': 'dummy_service_url',
-                'caption': 'URL of the dummy payment service',
+                'caption': _('URL of the dummy payment service'),
                 'default': SERVICE_URL,
                 'type': str,
             },
             {
                 'name': 'origin',
-                'caption': 'name of the requesting service, '
-                           'to present in the user interface',
+                'caption': _('name of the requesting service, '
+                           'to present in the user interface'),
                 'type': str,
                 'default': 'origin',
             },
             {
                 'name': 'consider_all_response_signed',
-                'caption': (
+                'caption': _(
                     'All response will be considered as signed '
                     '(to test payment locally for example, as you '
                     'cannot received the signed callback)'
@@ -115,13 +112,13 @@ class Payment(PaymentCommon):
             },
             {
                 'name': 'direct_notification_url',
-                'caption': 'direct notification url (replaced by automatic_return_url)',
+                'caption': _('direct notification url (replaced by automatic_return_url)'),
                 'type': str,
                 'deprecated': True,
             },
             {
                 'name': 'next_url (replaced by normal_return_url)',
-                'caption': 'Return URL for the user',
+                'caption': _('Return URL for the user'),
                 'type': str,
                 'deprecated': True,
             },
