@@ -36,12 +36,11 @@ from six.moves.urllib import parse as urlparse
 from six.moves.urllib import parse as urllib
 
 import base64
-from gettext import gettext as _
 import warnings
 
 from .common import (PaymentCommon, PaymentResponse, FORM, PAID, CANCELLED,
                      DENIED, ERROR, Form, ResponseError, force_text,
-                     force_byte)
+                     force_byte, _)
 from . import cb
 
 __all__ = ['sign', 'Payment']
@@ -214,7 +213,7 @@ class Payment(PaymentCommon):
             },
             {
                 'name': 'platform',
-                'caption': _('Plateforme cible'),
+                'caption': 'Plateforme cible',
                 'default': 'test',
                 'choices': (
                     ('test', 'Test'),
@@ -224,7 +223,7 @@ class Payment(PaymentCommon):
             },
             {
                 'name': 'site',
-                'caption': _('Numéro de site'),
+                'caption': 'Numéro de site',
                 'required': True,
                 'validation': lambda x: isinstance(x, six.string_types)
                 and x.isdigit() and len(x) == 7,
@@ -237,28 +236,28 @@ class Payment(PaymentCommon):
             },
             {
                 'name': 'rang',
-                'caption': _('Numéro de rang'),
+                'caption': 'Numéro de rang',
                 'required': True,
                 'validation': lambda x: isinstance(x, six.string_types)
-                and x.isdigit() and len(x) == 2,
+                and x.isdigit() and len(x) == 3,
             },
             {
                 'name': 'identifiant',
-                'caption': _('Identifiant'),
+                'caption': 'Identifiant',
                 'required': True,
                 'validation': lambda x: isinstance(x, six.string_types)
                 and x.isdigit() and (0 < len(x) < 10),
             },
             {
                 'name': 'shared_secret',
-                'caption': _('Secret partagé (clé HMAC)'),
+                'caption': 'Secret partagé (clé HMAC)',
                 'validation': lambda x: isinstance(x, str)
                 and all(a.lower() in '0123456789abcdef' for a in x),
                 'required': True,
             },
             {
                 'name': 'devise',
-                'caption': _('Devise'),
+                'caption': 'Devise',
                 'default': '978',
                 'choices': (
                     ('978', 'Euro'),
@@ -271,7 +270,7 @@ class Payment(PaymentCommon):
             },
             {
                 'name': 'capture_day',
-                'caption': _('Nombre de jours pour un paiement différé'),
+                'caption': 'Nombre de jours pour un paiement différé',
                 'default': '',
                 'required': False,
                 'validation': lambda x: isinstance(x, six.string_types)
@@ -312,7 +311,7 @@ class Payment(PaymentCommon):
     def request(self, amount, email, name=None, orderid=None, manual_validation=None, **kwargs):
         d = OrderedDict()
         d['PBX_SITE'] = force_text(self.site)
-        d['PBX_RANG'] = force_text(self.rang).strip()[-2:]
+        d['PBX_RANG'] = force_text(self.rang).strip()[-3:]
         d['PBX_IDENTIFIANT'] = force_text(self.identifiant)
         d['PBX_TOTAL'] = self.clean_amount(amount)
         d['PBX_DEVISE'] = force_text(self.devise)
