@@ -25,8 +25,6 @@ import re
 import unicodedata
 import xml.etree.ElementTree as ET
 
-from gettext import gettext as _
-
 import pytz
 
 import six
@@ -38,7 +36,7 @@ import zeep.exceptions
 from .systempayv2 import isonow
 from .common import (PaymentCommon, PaymentResponse, URL, PAID, DENIED,
                      CANCELLED, ERROR, ResponseError, PaymentException,
-                     WAITING, EXPIRED, force_text)
+                     WAITING, EXPIRED, force_text, _)
 
 WSDL_URL = 'https://www.tipi.budget.gouv.fr/tpa/services/mas_securite/contrat_paiement_securise/PaiementSecuriseService?wsdl'  # noqa: E501
 
