@@ -16,7 +16,6 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 import datetime
-from gettext import gettext as _
 import collections
 import hashlib
 import hmac
@@ -31,7 +30,7 @@ import requests
 import pytz
 
 from .common import (PaymentCommon, FORM, Form, PaymentResponse, PAID, ERROR,
-                     CANCELED, ResponseError, force_text)
+                     CANCELED, ResponseError, force_text, _)
 
 __all__ = ['Payment']
 
