@@ -26,10 +26,9 @@ import string
 import six
 from six.moves.urllib import parse as urlparse
 import warnings
-from gettext import gettext as _
 
 from .common import (PaymentCommon, PaymentResponse, PAID, DENIED, CANCELLED,
-                     ERROR, FORM, Form, ResponseError, force_text, force_byte)
+                     ERROR, FORM, Form, ResponseError, force_text, force_byte, _)
 from .cb import translate_cb_error_code
 
 __all__ = ['Payment']
@@ -135,20 +134,20 @@ PARAMETERS = [
     Parameter('vads_language', 'a', 12, length=2, default='fr'),
     Parameter('vads_order_id', 'an-', 13, max_length=32),
     Parameter('vads_order_info', 'an', 14, max_length=255,
-              description=_(u"Complément d'information 1")),
+              description="Complément d'information 1"),
     Parameter('vads_order_info2', 'an', 14, max_length=255,
-              description=_(u"Complément d'information 2")),
+              description="Complément d'information 2"),
     Parameter('vads_order_info3', 'an', 14, max_length=255,
-              description=_(u"Complément d'information 3")),
+              description="Complément d'information 3"),
     Parameter('vads_page_action', None, 46, needed=True, default='PAYMENT',
               choices=('PAYMENT',)),
     Parameter('vads_payment_cards', 'an;', 8, max_length=127, default='',
-              description=_(u'Liste des cartes de paiement acceptées'),
-              help_text=_(u'vide ou des valeurs sépareés par un point-virgule '
-                          'parmi AMEX, AURORE-MULTI, BUYSTER, CB, COFINOGA, '
-                          'E-CARTEBLEUE, MASTERCARD, JCB, MAESTRO, ONEY, '
-                          'ONEY_SANDBOX, PAYPAL, PAYPAL_SB, PAYSAFECARD, '
-                          'VISA')),
+              description='Liste des cartes de paiement acceptées',
+              help_text='vide ou des valeurs sépareés par un point-virgule '
+                        'parmi AMEX, AURORE-MULTI, BUYSTER, CB, COFINOGA, '
+                        'E-CARTEBLEUE, MASTERCARD, JCB, MAESTRO, ONEY, '
+                        'ONEY_SANDBOX, PAYPAL, PAYPAL_SB, PAYSAFECARD, '
+                        'VISA'),
     # must be SINGLE or MULTI with parameters
     Parameter('vads_payment_config', '', 7, default='SINGLE',
               choices=('SINGLE', 'MULTI'), needed=True),
@@ -156,7 +155,7 @@ PARAMETERS = [
               choices=('', 'NONE', 'POST', 'GET')),
     Parameter('signature', 'an', None, length=40),
     Parameter('vads_site_id', 'n', 2, length=8, needed=True,
-              description=_(u'Identifiant de la boutique')),
+              description='Identifiant de la boutique'),
     Parameter('vads_theme_config', 'ans', 32, max_length=255),
     Parameter(VADS_TRANS_DATE, 'n', 4, length=14, needed=True,
               default=isonow),
@@ -229,7 +228,7 @@ class Payment(PaymentCommon):
     signature_algo = 'sha1'
 
     description = {
-        'caption': 'SystemPay, système de paiment du groupe BPCE',
+        'caption': 'SystemPay, système de paiement du groupe BPCE',
         'parameters': [
             {
                 'name': 'normal_return_url',
@@ -244,19 +243,19 @@ class Payment(PaymentCommon):
             },
             {'name': 'service_url',
                 'default': service_url,
-                'caption': _(u'URL du service de paiment'),
-                'help_text': _(u'ne pas modifier si vous ne savez pas'),
+                'caption': 'URL du service de paiement',
+                'help_text': 'ne pas modifier si vous ne savez pas',
                 'validation': lambda x: x.startswith('http'),
                 'required': True, },
             {'name': 'secret_test',
-                'caption': _(u'Secret pour la configuration de TEST'),
+                'caption': 'Secret pour la configuration de TEST',
                 'validation': lambda value: str.isalnum(value),
                 'required': True, },
             {'name': 'secret_production',
-                'caption': _(u'Secret pour la configuration de PRODUCTION'),
+                'caption': 'Secret pour la configuration de PRODUCTION',
                 'validation': lambda value: str.isalnum(value), },
             {'name': 'signature_algo',
-                'caption': _(u'Algorithme de signature'),
+                'caption': 'Algorithme de signature',
                 'default': 'sha1',
                 'choices': (
                     ('sha1', 'SHA-1'),
